import typing
import collections.abc
import typing_extensions
import numpy.typing as npt

def hash_file(filepath) -> None:
    """Computes and returns the hash of the file.The returned string is prefixed with the hash type, like "{TYPE}:{HASH}"."""

def url(url_with_hash) -> None:
    """Return the url, with the hash on the query string."""
