"""
This module provides access to ID property types, used for
custom properties on data-blocks, accessed via ["key"]

 syntax.

* See info_quickstart-custom_properties for example usage.
* See bpy_types-custom_properties for types that support custom properties.

idprop.types.rst

:maxdepth: 1
:caption: Submodules

"""

import typing
import collections.abc
import typing_extensions
import numpy.typing as npt
from . import types as types
