import typing
import collections.abc
import typing_extensions
import numpy.typing as npt

class SpellChecker:
    """A basic spell checker."""

    uimsgs: typing.Any

    def check(self, txt) -> None:
        """

        :param txt:
        """

    @classmethod
    def split_words(cls, text) -> None:
        """

        :param text:
        """
